'''
Plots the MODIS MOD15A2H fPAR data for each flux tower site.
'''

import datetime
import os
import h5py
import numpy as np
from tqdm import tqdm
from matplotlib import pyplot

SOURCE_HDF = '/anx_lagr3/arthur.endsley/SMAP_L4C/applications/Western_Rangelands/L4_C_tower_site_drivers_NRv10_for_Yushu_sites.h5'
OUTPUT_DIR = '/home/arthur.endsley/plots_MOD15'

def main():
    'Plots fPAR, LAI for each site'
    with h5py.File(SOURCE_HDF, 'r') as hdf:
        n_sites = hdf['site_id'][:].size
        dates = [
            datetime.date(y, m, d)
            for y, m, d, _ in hdf['time'][:].tolist()
        ]
        for i in tqdm(range(n_sites)):
            pyplot.figure(figsize = (8, 5))
            fpar = hdf['drivers/fpar'][:,i].astype(np.float32)
            pyplot.plot(dates, fpar, alpha = 0.4)
            pyplot.title('Site #%d' % i)
            pyplot.savefig(os.path.join(OUTPUT_DIR, '%d.png' % i))
            pyplot.close()


if __name__ == '__main__':
    main()
