'''
Diagnostics of the L4C point process at Western Rangelands sites.
'''

import os
import datetime
import glob
import numpy as np
import pandas as pd

OUTPUT_FILE_TEMPLATE = '/anx_lagr3/arthur.endsley/SMAP_L4C/applications/Western_Rangelands/20230511_L4_C_NRv10_Western_Rangelands_sites_*.csv'
N_DAYS = 8041 # Number of days from 2000-01-01 to 2022-12-31

dt = [
    (datetime.datetime(2000, 1, 1) + datetime.timedelta(days = 1))\
        .strftime('%Y-%m-%d')
    for d in range(0, N_DAYS)
]

file_list = glob.glob(OUTPUT_FILE_TEMPLATE)
for filename in file_list:
    flux = os.path.basename(filename).split('.')[-2]
    if 'MULT' in flux or 'F' in flux:
        flux = '_'.join(flux.split('_')[-2:])
    else:
        flux = flux.split('_').pop()
    print(f'Diagnostics for {flux}:')
    df = pd.read_csv(filename, skiprows = 1)
    print(f'-- Min: {df["value"].min()}')
    print(f'-- Max: {df["value"].max()}')
    print(f'-- 2, 10, 90, 98th Percentiles: {np.nanpercentile(df["value"].values, (2, 10, 90, 98))}')
